//Добавление данных
function [Datas,..//Данные после добавления данных
          DatasHeaders..//Заголовки данных после добавления
          ]=AddDatas(Datas,..//Данные (исходные, к которым добавляем данные)
                     AddingDatas,..//Добавляем данные
                     DatasHeaders,..//Заголовки данных, к которым добавляем данные
                     AddingDatasHeaders,..//Заголовки добавляемых данных
                     Concating,..//Направление конкатенации ('r' - новые ряды, 'с' - новые колонки)
                     Replacing..//Замена значений величины новыми (в случае пересечения столбцов)
                     )
    //Проверяем входные данные
    [nOut,nArg] = argn();//Число аргументов
    if nArg < 2 then
        error('Function AddDatas takes 2, 3, 4, 5 or 6 arguments');
    end
    switch nArg
    case 2 then
        DatasHeaders = [];
        AddingDatasHeaders = [];
        Concating = 'r';
        Replacing = %f;
    case 3 then
        if isempty(DatasHeaders) then
            AddingDatasHeaders = [];
            Concating = 'r';
            Replacing = %f;
        else
            select type(DatasHeaders)
            case 1 then
                AddingDatasHeaders = DatasHeaders;
                Concating = 'r';
                Replacing = %f;
            case 4 then
                Replacing = DatasHeaders;
                AddingDatasHeaders = [];
                Concating = 'r';
            case 10 then
                Concating = DatasHeaders;
                AddingDatasHeaders = [];
                Replacing = %f;
            end
            DatasHeaders = [];
        end
    case 4 then
        if type(AddingDatasHeaders) == 4 then
            Replacing = AddingDatasHeaders;
            Concating = DatasHeaders;
            AddingDatasHeaders = [];
            DatasHeaders = [];
        else
            if isempty(DatasHeaders) then
                if (~isempty(Datas)) &&..
                   (~isempty(AddingDatasHeaders)) &&..
                   (type(AddingDatasHeaders) == 10) then
                    Concating = AddingDatasHeaders;
                    AddingDatasHeaders = [];
                else
                    Concating = 'r';
                end
            elseif type(DatasHeaders) == 1 then
                Concating = AddingDatasHeaders;
                AddingDatasHeaders = DatasHeaders;
                DatasHeaders = [];
            else
                Concating = 'r';
            end
            Replacing = %f;
        end
    case 5 then
        if type(Concating) == 4 then
            Replacing = Concating;
            if type(DatasHeaders) == 1 then
                Concating = AddingDatasHeaders;
                AddingDatasHeaders = DatasHeaders;
                DatasHeaders = [];
            else
                Concating = 'r';
            end
        else
            Replacing = %f;
        end
    end
    
    //Проверяем корректность аргументов
    if isempty(DatasHeaders) then
        if (size(AddingDatasHeaders)(1) > 1) ||..
           (type(AddingDatasHeaders) ~= 1) then
            if ~isempty(Datas) then
                error('The argument AddingDatasHeader of function AddDatas must be matrix 1xM of integer');
            elseif type(AddingDatasHeaders) ~= 10 then
                error('The argument AddingDatasHeader of function AddDatas must be matrix 1xM of string');
            end
        end
    else
        if (size(DatasHeaders)(1) ~= 1) ||..
           (type(DatasHeaders) ~= 10) then
            error('The argument DatasHeader of function AddDatas must be matrix 1xM of string');
        end
        if (size(AddingDatasHeaders)(1) > 1) ||..
           (~isempty(AddingDatasHeaders)) && (type(AddingDatasHeaders) ~= 10) then
            error('The argument AddingDatasHeader of function AddDatas must be matrix 1xM of string');
        end
    end
    if (type(Concating) ~= 10) || (size(Concating,'*') ~= 1) then
        error('The argument Concating of function AddDatas must be string scalar');
    end
    if (type(Replacing) ~= 4) || (size(Replacing,'*') > 1) then
        error('The argument Replacing of function AddDatas must be boolean scalar')
    end
    if ~IsTableDatas(Datas) then
        error('The argument Datas of function AddDatas must be matrix of real, boolean or string');
    end
    if ~IsTableDatas(AddingDatas) then
        error('The argument AddingDatas of function AddDatas must be matrix of real, boolean or strings');
    end
    if (type(DatasHeaders) == 10) &&..
       (~IsTableDatasAndHeaders(Datas,DatasHeaders)) then
        error('The numbers of columns of arguments DatasHeaders and Datas of functions AddDatas must be equality');
    end
    if (type(AddingDatasHeaders) == 10) &&..
       (~IsTableDatasAndHeaders(AddingDatas,AddingDatasHeaders)) then
        error('The numbers of columns of arguments AddingDatasHeaders and AddingDatas of functions AddDatas must be equality');
    end
    
    //Обрабатываем случаи пустых данных
    if size(AddingDatas,'*') == 0 then
        //Выходим из функции
        return;
    end
    if size(Datas,'*') == 0 then
        //Возвращаем передаваемые данные
        if (~isempty(AddingDatasHeaders)) &&..
           (type(AddingDatasHeaders) == 1) then
            Datas = AddingDatas(:,AddingDatasHeaders);//Выделяем данные
            DatasHeaders = [];//заголовок в таком случае пустой
        else
            Datas = AddingDatas;
            DatasHeaders = AddingDatasHeaders;
        end
        
        //Выходим из функции
        return;
    end
    
    //Приводим типы добавляемых данных
    if type(Datas) == 10 then
        AddingDatas = string(AddingDatas);//Приводим добавляемые данные к строковому типу
    elseif type(AddingDatas) == 10 then
        Datas = string(Datas);//Приводим исходные данные к строковому типу
    end
    
    //Добавляем данные
    switch Concating
    case 'r' then
        //Выдедяем непосредственно добавляемые данные
        if type(AddingDatasHeaders) == 1 then
            if isempty(AddingDatasHeaders) then
                addingDatas = AddingDatas;
            else
                addingDatas = AddingDatas(:,AddingDatasHeaders);
            end
        else
            addingDatas = SelectionDatas(AddingDatasHeaders,..//Заголовок таблицы данных (еще не разделенных)
                                         DatasHeaders,..//Заголовок выделенных данных
                                         AddingDatas..//Данные (отдельно от заголовка, не разделенные)
                                         );
        end
        
        //Добавляем данные
        Datas = [Datas;addingDatas];
    case 'c' then
        //Числа конкатенуемых данных
        nAddingDatas = size(AddingDatas)(1);//Число добавляемых данных
        nDatas = size(Datas)(1);//Число исходных данных
        
        //Приводим при необходимости числа конкатенуемых данных
        if nAddingDatas == 1 then
            AddingDatas = repmat(AddingDatas',[1,nDatas])';
        elseif nDatas == 1 then
            Datas = repmat(Datas',[1,nAddingDatas])';
        end
        
        //Конкатенуем данные
        if isempty(DatasHeaders) then
            if isempty(AddingDatasHeaders) then
                Datas = [Datas,AddingDatas];
            else
                Datas = [Datas,AddingDatas(:,AddingDatasHeaders)];
            end
        else
            //Получаем заголовки добавляемых колонок
            [a,AddingDatasHeadersInd] = members(AddingDatasHeaders,..
                                                DatasHeaders); clear a;
            addingDatasHeadersInd = (AddingDatasHeadersInd == 0);//Индексы добавляемых данных
            addingDatasHeaders = AddingDatasHeaders(addingDatasHeadersInd);//Заголовки добавляемых данных
            
            //Выделяем добавляемые столбцы
            addingDatas = AddingDatas(:,addingDatasHeadersInd);
            
            //Обновляем данные при необходимости
            if Replacing then
                replacingInd = AddingDatasHeadersInd(~addingDatasHeadersInd);
                Datas(:,replacingInd) = AddingDatas(:,~addingDatasHeadersInd);
            end
            
            //Добавляем данные и их заголовки
            Datas = [Datas,addingDatas];
            DatasHeaders = [DatasHeaders,addingDatasHeaders];
        end
    else
        error('The values of argument Concating of function AddDatas must be ""r"" or ""c""');
    end
endfunction
