//Расчет результатов
function [rezults,..//Результаты расчета
          rezultsHeaders..//Заголовки результатов
          ]=CountRezults(inputDatas,..//Входные данные
                         inputDatasHeaders,..//Заголовки входных данных
                         Functions,..//Функции
                         argumentsNames,..//Имена (индексы) аргументов
                         rezultsNames,..//Имена результатов
                         isVectorized..//Векторизованы ли функции
                         )
    //Проверяем аргументы
    [nOut,nArg] = argn();//Число аргументов
    if nArg < 4 then
        error('Function CountRezult takes 4, 5 or 6 arguments');
    end
    switch nArg
    case 4 then
        rezultsNames = argumentsNames;
        argumentsNames = Functions;
        Functions = inputDatasHeaders;
        inputDatasHeaders = [];
        isVectorized = %t;
    case 5 then
        if type(rezultsNames) == 4 then
            isVectorized = rezultsNames;
            rezultsNames = argumentsNames;
            argumentsNames = Functions;
            Functions = inputDatasHeaders;
            inputDatasHeaders = [];
        else
            isVectorized = %t;
        end
    end
    
    //Проверяем корректность аргументов
    if ~IsTableDatas(inputDatas) then
        error('The argument inputDatas of function CountRezults must be matrix of real, string or boolean');
    end
    if (~isempty(inputDatasHeaders)) && (type(inputDatasHeaders) ~= 10) then
        error('The inputDatasHeaders argument of function CountRezults must be matrix 1xM of string');
    end
    if (~IsTableDatasAndHeaders(inputDatas,inputDatasHeaders)) then
        error('The numbers of columns of arguments inputDatasHeaders and inputDatas of functions CountRezults must be equality');
    end
    if IsCountFunction(Functions) then
        Functions = DatasToCell(Functions);
    elseif type(Functions) == 10 then
        Functions = StrFunctionsToCell(Functions);//Приводим к cell-массиву
    elseif type(Functions) ~= 17 then
        error('The argument Functions of function CountRezults must be cell-array, function or matrix of string');
    end
    nFunctions = size(Functions,'*');//Число функций
    if isempty(argumentsNames) then
        argumentsNames = cell(1,nFunctions);//Создаем cell-массив имен аргументов
        for ind=1:nFunctions
            argumentsNames{ind} = [];//Массиву имен присваиваем пустые массивы имен
        end
    elseif or(type(argumentsNames) == [1,10]) then
        if nFunctions == 1 then
            argumentsNames = matrix(argumentsNames,1,-1);//Приводим к матрице-строке
            argumentsNames = DatasToCell(argumentsNames);
        else
            error('The argument argumentsNames of function CountRezults must be matrix of strings or integer indexes 1xM or cell-array');
        end
    elseif type(argumentsNames) ~= 17 then
        error('The argument argumentsNames of function CountRezults must be cell-array or matrix of string or integer indexes 1xM');
    end
    if ~isempty(rezultsNames) then
        if type(rezultsNames) == 10 then
            if nFunctions == 1 then
                rezultsNames = matrix(rezultsNames,1,-1);
                rezultsNames = DatasToCell(rezultsNames);
            else
                error('The argument argumentsNames of function CountRezults must be matrix of strings 1xM or cell-array');
            end
        elseif type(rezultsNames) ~= 17 then
            error('The argument rezultsNames of function CountRezults must be cell-array or matrix of string 1xM');
        end
        if size(rezultsNames,'*') ~= nFunctions then
            error('The numbera of elements of arguments Functions and rezultsNames must be equality');
        end
    end
    if (type(isVectorized) ~= 4) || (size(isVectorized)(1) ~= 1) then
        error('The argument isVectorized of function CountRezults must be matrix 1xM of bool');
    end
    if size(isVectorized,'*') == 1 then
      isVectorized = repmat(isVectorized,[1,nFunctions]);
    elseif size(isVectorized,'*') ~= nFunctions then
        error('The numbera of elements of arguments Functions and isVectorized must be equality');
    end
    if size(argumentsNames,'*') ~= nFunctions then
        error('The numbera of elements of arguments Functions and argumentsNames must be equality');
    end
    
    //Вычисляем значение функций
    rezults = [];
    if nOut > 1 then
        rezultsHeaders = [];
    end
    for ind=1:size(Functions,'*')
        if (nOut > 1) && (~isempty(rezultsNames)) then
            rezultsHeaders = [rezultsHeaders,matrix(rezultsNames{ind},1,-1)];
        end
        rezult = CountFunction(inputDatas,..
                               inputDatasHeaders,..
                               Functions{ind},..
                               argumentsNames{ind},..
                               isVectorized(ind));
        rezults = [rezults,rezult];
    end
endfunction

//Перевод функций из матрицы строк в cell-массив
function cellFunctions=StrFunctionsToCell(strFunctionsNames)
    //Приводим данные к матрице-строке
    strFunctionsNames = matrix(strFunctionsNames,1,-1);
    
    //Создаем пустой cell-массив функций
    nFunctions = size(strFunctionsNames,'*');//Число функций
    cellFunctions = cell(1,nFunctions);//cell-массив функций
    
    //Заполняем cell-массив функциями (c параметрами)
    for ind=1:nFunctions
        cellFunctions{ind} = strFunctionsNames(ind);
    end
endfunction

//представление функции в виде cell-массива из одного элемента
function cellDatas=DatasToCell(Data)
    //Создаем пустой cell-массив функций
    cellDatas = cell(1,1);//cell-массив функций
    
    //Заполняем cell-массив функциями (c параметрами)
    cellDatas{1} = Data;
endfunction
