//Разделение данных на входные и выходные данные
function [inputData,..//Входные данные
          outputData,..//Выходные данные
          inputHeader,..//Заголовки (или индексы в случае без заголовков) входных данных
          outputHeader..//заголовки (или индексы в случае без заголовков) выходных данных
          ]=InputOutputDataSplit(Header,..//Заголовок таблицы данных (еще не разделенных)
                                 Datas,..//Данные (отдельно от заголовка, не разделенные)
                                 inputHeader,..//Заголовок входных данных
                                 outputHeader..//Заголовок выходных данных
                                 )
    //Проверяем входные данные
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('Function InputOutputDataSplit takes 2, 3 or 4 arguments');
    end
    select nArg
    case 2 then
        inputHeader = Datas;
        Datas = Header;
        Header = [];
        outputHeader = [];
    case 3 then
        if (~isempty(Header)) &&..
           (type(inputHeader) == 1) then
            outputHeader = inputHeader;
            inputHeader = Datas;
            Datas = Header;
            Header = [];
        else
            outputHeader = [];
        end
    end
    
    //Проверяем корректность входных данных
    if isempty(Header) then
        if isempty(inputHeader) || (type(inputHeader) ~= 1) then
            error('The argument inputHeader of function InputOutputDataSplit must be integer');
        end
        if (~isempty(outputHeader)) && (type(outputHeader) ~= 1) then
            error('The argument outputHeader of function InputOutputDataSplit must be integer');
        end
    else
        if type(Header) ~= 10 then
            error('The argument Header of function InputOutputDataSplit must be string');
        end
        if (isempty(inputHeader)) || (type(inputHeader) ~= 10) then
            error('The argument inputHeader of function InputOutputDataSplit must be string');
        end
        if (~isempty(outputHeader)) && (type(outputHeader) ~= 10) then
            error('The argument outputHeader of function InputOutputDataSplit must be string');
        end
    end
    if ~IsTableDatas(Datas) then
        error('The argument Datas of function InputOutputDataSplit must be matrix of real, boolean or string');
    end
    if (~IsTableDatasAndHeaders(Datas,Header)) then
        error('The numbers of columns of arguments Header and Datas of functions InputOutputDataSplit must be equality');
    end
    
    //Получаем входные и выходные данные
    [inputData,inputHeader]=SelectionDatas(Header,inputHeader,Datas);//Входные данные
    if isempty(outputHeader) then
        [outputData,outputHeader]=SelectionAllDatasExcept(Header,inputHeader,Datas);//Выходные данные
    else
        [outputData,outputHeader]=SelectionDatas(Header,outputHeader,Datas);//Выходные данные
    end
endfunction
